@@ -12,6 +12,7 @@ import glob
 import platform
 import sys
 import subprocess
+from molSimplify.utils.metaclasses import Singleton
 
 # Dictionary containing atomic mass, atomic number, covalent radius, num valence electrons
 # Data from http://www.webelements.com/ (last accessed May 13th 2015)
@@ -203,7 +204,7 @@ heavy_metals_and_metalloids = [
     'Md', 'md', 'MD', 'mendelevium', 'No', 'no', 'NO', 'nobelium',
     'Lr', 'lr', 'LR', 'lawrencium']
 
-### The metals list below contains only TMs. See metalslist function for logic.
+# ## The metals list below contains only TMs. See metalslist function for logic.
 metalslist = [
     'Sc', 'sc', 'SC', 'scandium', 'Ti', 'ti', 'TI', 'titanium',
     'V', 'v', 'vanadium', 'Cr', 'cr', 'CR', 'chromium',
@@ -467,7 +468,7 @@ def mybash(cmd):
 
 
 # Defines global variables used throughout the code
-class globalvars:
+class globalvars(metaclass=Singleton):
     """Globalvars class. Defines global variables used throughout the code, including periodic table.
     """
     def __init__(self):
@@ -484,10 +485,10 @@ class globalvars:
         s += 'J.P. Janet, T. Z. H. Gani, A. H. Steeves, E. I. Ioannidis, H. J. Kulik. Ind. Eng. Chem. Res. 2017, 56(17), 4898-4910.\n'
         # About message
         self.about = s
-        ###### GET INFORMATION ######
+        # ##### GET INFORMATION ######
         runfromcmd = False
         try:
-            ### check if running through commandline ###
+            # ## check if running through commandline ###
             if sys.stdin.isatty():
                 # running through command line
                 runfromcmd = True
@@ -495,7 +496,7 @@ class globalvars:
                 runfromcmd = False
         except AttributeError:  # if sys.stdin does not have an isatty method
             runfromcmd = True
-        ### get running os ###
+        # ## get running os ###
         self.linux, self.osx = False, False
         if platform.system().lower() in 'linux':
             self.linux = True
@@ -518,7 +519,7 @@ class globalvars:
         self.chemdbdir = ''
         self.multiwfn = ''
         self.custom_path = False
-        ###### check for ~/.molSimplify ######
+        # ##### check for ~/.molSimplify ######
         if glob.glob(homedir + '/.' + self.PROGRAM):
             with open(homedir + '/.' + self.PROGRAM, 'r') as fin:
                 s = [_f for _f in fin.read().splitlines() if _f]
