@@ -2,6 +2,7 @@ import numpy as np
 
 from molSimplify.Scripts.geometry import distance
 
+
 def fpriority(mol):
     # setting up variables
     fidx_list = []
@@ -9,8 +10,8 @@ def fpriority(mol):
     satno_list = []
     ref_list = []
     fd_list = []
-    fa_list = []
-    idx_list = [0] * 6
+    # fa_list = []
+    # idx_list = [0] * 6
     exit_signal = True
     # getting bond-order matrix
     mol.convert2OBMol()
@@ -36,7 +37,7 @@ def fpriority(mol):
     for satno in set(satno_list):
         satnocount = satno_list.count(satno)
         if satnocount > 1:
-            s_sel_list = [i for i,atno in enumerate(satno_list) if atno is satno]
+            s_sel_list = [i for i, atno in enumerate(satno_list) if atno is satno]
             exit_signal = False
 
     for i in range(len(fidx_list)):
@@ -70,7 +71,7 @@ def fpriority(mol):
                         BO = int(BOMatrix[sidx][tidx])
                         tatno_str = str(mol.getAtom(tidx).atno)
                         ls.append(BO * tatno_str)
-                sorted(ls,reverse=True)
+                sorted(ls, reverse=True)
                 for j in ls:
                     atno_list.append(j)
                 a = ''.join(atno_list)
@@ -182,46 +183,47 @@ def fpriority(mol):
 
     return fpriority_list, fd_list, idx_list
 
+
 def fsym(mol):
     # getting idxs of interest
-    midx = mol.findMetal()[0] # monometallic complexes
-    fidx_list = mol.getBondedAtoms(midx) # list of idx of the first-coord sphere
+    midx = mol.findMetal()[0]  # monometallic complexes
+    fidx_list = mol.getBondedAtoms(midx)  # list of idx of the first-coord sphere
     fsym_list = []
     for idx in fidx_list:
         sym = mol.getAtom(idx).sym
         fsym_list.append(sym)
-    
-    return fsym_list    
+    return fsym_list
+
 
 def fvalency(mol):
     # getting idxs of interest
-    midx = mol.findMetal()[0] # monometallic complexes
-    fidx_list = mol.getBondedAtoms(midx) # list of idx of the first-coord sphere
+    midx = mol.findMetal()[0]  # monometallic complexes
+    fidx_list = mol.getBondedAtoms(midx)  # list of idx of the first-coord sphere
     fvalency_list = []
     for idx in fidx_list:
         valency = len(mol.getBondedAtoms(idx)) - 1
         fvalency_list.append(valency)
-    
-    return fvalency_list    
+    return fvalency_list
 
-def fcharge(mol,charge,bond=False):
+
+def fcharge(mol, charge, bond=False):
     # getting idxs of interest
-    midx = mol.findMetal()[0] # monometallic complexes
-    fidx_list = mol.getBondedAtoms(midx) # list of idx of the first-coord sphere
-    mol.calcCharges(charge,bond)
+    midx = mol.findMetal()[0]  # monometallic complexes
+    fidx_list = mol.getBondedAtoms(midx)  # list of idx of the first-coord sphere
+    mol.calcCharges(charge, bond)
     fcharge_list = []
     for idx in fidx_list:
         partialq = mol.partialcharges[idx]
         fcharge_list.append(float(partialq))
-    
     return fcharge_list
 
-def scharge_ave(mol,charge,bond=False):
+
+def scharge_ave(mol, charge, bond=False):
     mol.calcCharges(charge)
     # getting idxs of interest
-    midx = mol.findMetal()[0] # monometallic complexes
-    fidx_list = mol.getBondedAtoms(midx) # list of idx of the first-coord sphere
-    mol.calcCharges(charge,bond)
+    midx = mol.findMetal()[0]  # monometallic complexes
+    fidx_list = mol.getBondedAtoms(midx)  # list of idx of the first-coord sphere
+    mol.calcCharges(charge, bond)
     sidx_list = [mol.getBondedAtoms(fidx) for fidx in fidx_list]
     scharge_ave_list = []
     for i in range(len(sidx_list)):
@@ -229,7 +231,7 @@ def scharge_ave(mol,charge,bond=False):
         for j in range(len(sidx_list[i])):
             idx = sidx_list[i][j]
             if idx is not midx:
-                partialq =+ mol.partialcharges[idx]
+                partialq += mol.partialcharges[idx]
         charge_ave = partialq/len(sidx_list[i])
         scharge_ave_list.append(float(charge_ave))
 
@@ -245,15 +247,16 @@ def scharge_ave(mol,charge,bond=False):
 #         fcoord = mol.getAtom(idx).coords()
 #         d = distance(mcoord,fcoord)
 #         fdistance_list.append(float(d))
-    
+
 #     return fdistance_list
 
-def all_prop(mol,charge,bond=False):
+
+def all_prop(mol, charge, bond=False):
     fprio_list, fd_list, idx_list = fpriority(mol)
     # fsym_list = fsym(mol)
     fva_list = fvalency(mol)
-    fq_list = fcharge(mol,charge,bond)
-    sq_ave_list = scharge_ave(mol,charge,bond)
+    fq_list = fcharge(mol, charge, bond)
+    sq_ave_list = scharge_ave(mol, charge, bond)
     # fd_list = fdistance(mol)
     fd_list = np.array(fd_list)
     idx_list = idx_list(fprio_list, fd_list)
@@ -268,12 +271,13 @@ def all_prop(mol,charge,bond=False):
 
     return prop_list
 
-def f_prop(mol,charge,bond=False):
+
+def f_prop(mol, charge, bond=False):
     fprio_list, fd_list, idx_list = fpriority(mol)
     # fsym_list = fsym(mol)
     fva_list = fvalency(mol)
-    fq_list = fcharge(mol,charge,bond)
-    sq_ave_list = scharge_ave(mol,charge,bond)
+    fq_list = fcharge(mol, charge, bond)
+    # sq_ave_list = scharge_ave(mol, charge, bond)
     # fd_list = fdistance(mol)
     idx_list = idx_list(fprio_list, fd_list)
     # rearranging
@@ -285,10 +289,11 @@ def f_prop(mol,charge,bond=False):
 
     return prop_list
 
-def features(mol,charge,bond=False):
+
+def features(mol, charge, bond=False):
     feature = []
     feature_names = []
-    prop_list = all_prop(mol,charge,bond)
+    prop_list = all_prop(mol, charge, bond)
     midx = mol.findMetal()[0]
     manto = mol.getAtom(midx).atno
     # a = np.array(prop_list)
@@ -302,17 +307,21 @@ def features(mol,charge,bond=False):
     # for i in range(len(feature_list)):
     #     for j in range(len(feature_list[i])):
     #         feature.append(feature_list[i][j])
-    feature_names = ['mato','fatno_1','fatno_2','fatno_3','fatno_4','fatno_5','fatno_6','fq_1','fq_2','fq_3','fq_4',
-    'fq_5','fq_6','sqave_1','sqave_2','sqave_3','sqave_4','sqave_5','sqave_6','fval_1','fval_2','fval_3','fval_4',
-    'fval_5','fval_6','bl_1','bl_2','bl_3','bl_4','bl_5','bl_6']
+    feature_names = [
+        'mato', 'fatno_1', 'fatno_2', 'fatno_3', 'fatno_4', 'fatno_5', 'fatno_6',
+        'fq_1', 'fq_2', 'fq_3', 'fq_4', 'fq_5', 'fq_6',
+        'sqave_1', 'sqave_2', 'sqave_3', 'sqave_4', 'sqave_5', 'sqave_6',
+        'fval_1', 'fval_2', 'fval_3', 'fval_4', 'fval_5', 'fval_6',
+        'bl_1', 'bl_2', 'bl_3', 'bl_4', 'bl_5', 'bl_6']
 
     return feature_names, feature
     # return feature
 
-def ffeatures(mol,charge,bond=False):
+
+def ffeatures(mol, charge, bond=False):
     feature = []
     feature_names = []
-    prop_list = f_prop(mol,charge,bond)
+    prop_list = f_prop(mol, charge, bond)
     midx = mol.findMetal()[0]
     manto = mol.getAtom(midx).atno
     fatno_list = [int(str(i).split('.')[0]) for i in prop_list[:6]]
@@ -328,7 +337,9 @@ def ffeatures(mol,charge,bond=False):
     # for i in range(len(feature_list)):
     #     for j in range(len(feature_list[i])):
     #         feature.append(feature_list[i][j])
-    feature_names = ['mato','fatno_1','fatno_2','fatno_3','fatno_4','fatno_5','fatno_6','fq_1','fq_2','fq_3','fq_4',
-    'fq_5','fq_6','fval_1','fval_2','fval_3','fval_4','fval_5','fval_6']
+    feature_names = [
+        'mato', 'fatno_1', 'fatno_2', 'fatno_3', 'fatno_4', 'fatno_5', 'fatno_6',
+        'fq_1', 'fq_2', 'fq_3', 'fq_4', 'fq_5', 'fq_6',
+        'fval_1', 'fval_2', 'fval_3', 'fval_4', 'fval_5', 'fval_6']
 
     return feature_names, feature
