@@ -15,14 +15,14 @@ from molSimplify.Classes.mol3D import mol3D
 
 def multitcgen(args, strfiles):
     """Generate multiple terachem input files at once.
-        
+
         Parameters
         ----------
             args : Namespace
                 Namespace of input arguments.
             strfiles : list
                 List of xyz files produced.
-        
+
         Returns
         -------
             jobdirs : list
@@ -65,7 +65,7 @@ def tcgen(args, strfiles, method):
                 List of xyz files produced.
             method : str
                 Name of method to use, (e.g. B3LYP).
-        
+
         Returns
         -------
             jobdirs : list
@@ -104,7 +104,7 @@ def tcgen(args, strfiles, method):
         else:
             nametrunc = coordname
         if not os.path.exists(rdir+'/'+nametrunc) and not args.jobdir:
-            os.mkdir(rdir+'/'+nametrunc)
+            os.makedirs(rdir+'/'+nametrunc)
         mdir = rdir+'/'+nametrunc
         if method:
             if method[0] == 'U' or method[0] == 'u':
@@ -113,7 +113,7 @@ def tcgen(args, strfiles, method):
                 mmd = '/'+method
             mdir = rdir+'/'+nametrunc+mmd
             if not os.path.exists(mdir):
-                os.mkdir(mdir)
+                os.makedirs(mdir)
         if not args.jobdir:
             jobdirs.append(mdir)
             if not args.reportonly:
@@ -198,56 +198,55 @@ def tcgen(args, strfiles, method):
     # Now we're ready to start building the input file
     if not args.jobdir:
         for i, jobd in enumerate(jobdirs):
-            output = open(jobd+'/terachem_input', 'w')
-            output.write('# file created with %s\n' % globs.PROGRAM)
-            jobparams['coordinates'] = coordfs[i]
-            for keys in list(jobparams.keys()):
-                output.write('%s %s\n' % (keys, jobparams[keys]))
-            if jobparams['run'] == 'minimize':
-                output.write('new_minimizer yes\n')
-                # output.write('min_coordinates cartesian\n')
-            if args.tc_fix_dihedral:
-                temp = mol3D()
-                temp.readfromxyz(strfiles[i])
-                metal_ind = temp.findMetal()
-                fixed_atoms = list()
-                fixed_atoms = temp.getBondedAtoms(metal_ind)
-                fixed_atoms = [str(int(i)+1)
-                               for i in fixed_atoms]  # 1-based indices
-                string_to_write = 'dihedral 0 ' + '_'.join(fixed_atoms)
-                # print(string_to_write)
-                output.write('$constraint_set \n')
-                output.write(string_to_write + '\n')
-            output.write('end\n')
-            output.close()
+            with open(jobd+'/terachem_input', 'w') as output:
+                output.write('# file created with %s\n' % globs.PROGRAM)
+                jobparams['coordinates'] = coordfs[i]
+                for keys in list(jobparams.keys()):
+                    output.write('%s %s\n' % (keys, jobparams[keys]))
+                if jobparams['run'] == 'minimize':
+                    output.write('new_minimizer yes\n')
+                    # output.write('min_coordinates cartesian\n')
+                if args.tc_fix_dihedral:
+                    temp = mol3D()
+                    temp.readfromxyz(strfiles[i])
+                    metal_ind = temp.findMetal()
+                    fixed_atoms = list()
+                    fixed_atoms = temp.getBondedAtoms(metal_ind)
+                    fixed_atoms = [str(int(i)+1)
+                                   for i in fixed_atoms]  # 1-based indices
+                    string_to_write = 'dihedral 0 ' + '_'.join(fixed_atoms)
+                    # print(string_to_write)
+                    output.write('$constraint_set \n')
+                    output.write(string_to_write + '\n')
+                output.write('end\n')
     elif args.jobdir:
         for i, jobd in enumerate(jobdirs):
             print(('jobd is ' + jobd))
             if args.name:
-                output = open(jobd + '/'+args.name + '.in', 'w')
+                output_filename = jobd + '/'+args.name + '.in'
             else:
-                output = open(jobd+'/terachem_input', 'w')
-            output.write('# file created with %s\n' % globs.PROGRAM)
-            jobparams['coordinates'] = coordfs[i]
-            for keys in list(jobparams.keys()):
-                output.write('%s %s\n' % (keys, jobparams[keys]))
-            if jobparams['run'] == 'minimize':
-                output.write('new_minimizer yes\n')
-                # output.write('min_coordinates cartesian\n')
-            if args.tc_fix_dihedral:
-                temp = mol3D()
-                temp.readfromxyz(strfiles[i])
-                metal_ind = temp.findMetal()
-                fixed_atoms = list()
-                fixed_atoms = temp.getBondedAtoms(metal_ind)
-                fixed_atoms = [str(int(i)+1)
-                               for i in fixed_atoms]  # 1-based indices
-                string_to_write = 'dihedral 0 ' + '_'.join(fixed_atoms)
-                # print(string_to_write)
-                output.write('$constraint_set \n')
-                output.write(string_to_write + '\n')
-            output.write('end\n')
-            output.close()
+                output_filename = jobd+'/terachem_input'
+            with open(output_filename, 'w') as output:
+                output.write('# file created with %s\n' % globs.PROGRAM)
+                jobparams['coordinates'] = coordfs[i]
+                for keys in list(jobparams.keys()):
+                    output.write('%s %s\n' % (keys, jobparams[keys]))
+                if jobparams['run'] == 'minimize':
+                    output.write('new_minimizer yes\n')
+                    # output.write('min_coordinates cartesian\n')
+                if args.tc_fix_dihedral:
+                    temp = mol3D()
+                    temp.readfromxyz(strfiles[i])
+                    metal_ind = temp.findMetal()
+                    fixed_atoms = list()
+                    fixed_atoms = temp.getBondedAtoms(metal_ind)
+                    fixed_atoms = [str(int(i)+1)
+                                   for i in fixed_atoms]  # 1-based indices
+                    string_to_write = 'dihedral 0 ' + '_'.join(fixed_atoms)
+                    # print(string_to_write)
+                    output.write('$constraint_set \n')
+                    output.write(string_to_write + '\n')
+                output.write('end\n')
     return jobdirs
 
 
@@ -258,7 +257,7 @@ def xyz2gxyz(filename):
         ----------
             filename : str
                 Filename of xyz file.
-        
+
         Returns
         -------
             gfilename : str
@@ -282,7 +281,7 @@ def multigamgen(args, strfiles):
                 Namespace of input arguments.
             strfiles : list
                 List of xyz files produced.
-        
+
         Returns
         -------
             jobdirs : list
@@ -316,7 +315,7 @@ def gamgen(args, strfiles, method):
                 List of xyz files produced.
             method : str
                 Name of method to use, (e.g. B3LYP).
-        
+
         Returns
         -------
             jobdirs : list
@@ -364,8 +363,12 @@ def gamgen(args, strfiles, method):
                 os.mkdir(mdir)
         jobdirs.append(mdir)
         shutil.copy2(xyzf, mdir)
-        shutil.copy2(xyzf.replace('.gxyz', '.molinp'),
-                     mdir.replace('.gxyz', '.molinp'))
+        # Try copying molinp and report file to jobdir
+        try:
+            shutil.copy2(xyzf.replace('.gxyz', '.molinp'),
+                         mdir.replace('.gxyz', '.molinp'))
+        except FileNotFoundError:
+            pass
         try:
             shutil.copy2(xyzf.replace('.xyz', '.report'),
                          mdir.replace('.xyz', '.report'))
@@ -393,29 +396,28 @@ def gamgen(args, strfiles, method):
         jobparams['run'] = 'SADPOINT'
     # Now we're ready to start building the input file and the job script
     for i, jobd in enumerate(jobdirs):
-        output = open(jobd+'/gam.inp', 'w')
-        f = open(coordfs[i])
-        s = f.read()  # read coordinates
-        f.close()
+        output = []
+        with open(coordfs[i]) as f:
+            s = f.read()  # read coordinates
         jobparams['coordinates'] = s
-        output.write('! File created using %s\n' % globs.PROGRAM)
+        output.append('! File created using %s\n' % globs.PROGRAM)
         # write $BASIS block
-        output.write(' $BASIS ')
+        output.append(' $BASIS ')
         if args.ngauss:
-            output.write(' GBASIS='+jobparams['GBASIS'])
-            output.write(' NGAUSS='+jobparams['NGAUSS'])
+            output.append(' GBASIS='+jobparams['GBASIS'])
+            output.append(' NGAUSS='+jobparams['NGAUSS'])
         else:
-            output.write(' GBASIS='+jobparams['GBASIS'])
+            output.append(' GBASIS='+jobparams['GBASIS'])
         if args.ndfunc:
-            output.write(' NDFUNC='+args.ndfunc)
+            output.append(' NDFUNC='+args.ndfunc)
         if args.npfunc:
-            output.write(' NPFUNC='+args.npfunc)
-        output.write(' $END\n')
+            output.append(' NPFUNC='+args.npfunc)
+        output.append(' $END\n')
         # write $SYSTEM block
-        output.write(' $SYSTEM ')
+        output.append(' $SYSTEM ')
         # check if MWORDS specified by the user
         if not args.sysoption or not ('MWORDS' in args.sysoption):
-            output.write(' MWORDS=16')
+            output.append(' MWORDS=16')
         # write additional options
         if (args.sysoption):
             if len(args.sysoption) % 2 > 0:
@@ -423,17 +425,17 @@ def gamgen(args, strfiles, method):
             else:
                 for elem in range(0, int(0.5*len(args.sysoption))):
                     key, val = args.sysoption[2*elem], args.sysoption[2*elem+1]
-                    output.write(' '+key+'='+val+' ')
-        output.write(' $END\n')
+                    output.append(' '+key+'='+val+' ')
+        output.append(' $END\n')
         # write CONTRL block
-        output.write(' $CONTRL SCFTYP='+jobparams['SCFTYP']+' DFTTYP=')
-        output.write(jobparams['DFTTYP']+' RUNTYP='+jobparams['RUNTYP'])
-        output.write('\n  ICHARG='+jobparams['ICHARG']+' MULT=')
+        output.append(' $CONTRL SCFTYP='+jobparams['SCFTYP']+' DFTTYP=')
+        output.append(jobparams['DFTTYP']+' RUNTYP='+jobparams['RUNTYP'])
+        output.append('\n  ICHARG='+jobparams['ICHARG']+' MULT=')
         # check if CC basis set specified and add spherical
         if 'CC' in jobparams['GBASIS']:
-            output.write(jobparams['MULT']+' ISPHER=1\n')
+            output.append(jobparams['MULT']+' ISPHER=1\n')
         else:
-            output.write(jobparams['MULT']+'\n')
+            output.append(jobparams['MULT']+'\n')
         # write additional options
         if (args.ctrloption):
             if len(args.ctrloption) % 2 > 0:
@@ -442,17 +444,17 @@ def gamgen(args, strfiles, method):
                 for elem in range(0, int(0.5*len(args.ctrloption))):
                     key, val = args.ctrloption[2 *
                                                elem], args.ctrloption[2*elem+1]
-                    output.write(' '+key+'='+val+' ')
-        output.write(' $END\n')
+                    output.append(' '+key+'='+val+' ')
+        output.append(' $END\n')
         # write $SCF block
-        output.write(' $SCF ')
+        output.append(' $SCF ')
         # check if options specified by the user
         if not args.scfoption or not ('DIRSCF' in args.scfoption):
-            output.write(' DIRSCF=.TRUE.')
+            output.append(' DIRSCF=.TRUE.')
         if not args.scfoption or not ('DIIS' in args.scfoption):
-            output.write(' DIIS=.TRUE.')
+            output.append(' DIIS=.TRUE.')
         if not args.scfoption or not ('SHIFT' in args.scfoption):
-            output.write(' SHIFT=.TRUE.')
+            output.append(' SHIFT=.TRUE.')
         # write additional options
         if (args.scfoption):
             if len(args.scfoption) % 2 != 0:
@@ -460,13 +462,13 @@ def gamgen(args, strfiles, method):
             else:
                 for elem in range(0, int(0.5*len(args.scfoption))):
                     key, val = args.scfoption[2*elem], args.scfoption[2*elem+1]
-                    output.write(' '+key+'='+val+' ')
-        output.write(' $END\n')
+                    output.append(' '+key+'='+val+' ')
+        output.append(' $END\n')
         # write $STATPT block
-        output.write(' $STATPT ')
+        output.append(' $STATPT ')
         # check if NSTEP specified by the user
         if not args.statoption or not ('NSTEP' in args.statoption):
-            output.write(' NSTEP=100')
+            output.append(' NSTEP=100')
         # write additional options
         if (args.statoption):
             if len(args.statoption) % 2 > 0:
@@ -475,25 +477,26 @@ def gamgen(args, strfiles, method):
                 for elem in range(0, int(0.5*len(args.statoption))):
                     key, val = args.statoption[2 *
                                                elem], args.statoption[2*elem+1]
-                    output.write(' '+key+'='+val+' ')
-        output.write(' $END\n')
+                    output.append(' '+key+'='+val+' ')
+        output.append(' $END\n')
         # write $DATA block
-        output.write(' $DATA\n')
-        output.write(jobparams['coordinates']+' $END\n')
-        output.close()
+        output.append(' $DATA\n')
+        output.append(jobparams['coordinates']+' $END\n')
+        with open(jobd+'/gam.inp', 'w') as f:
+            f.writelines(output)
     return jobdirs
 
 
 def multiqgen(args, strfiles):
     """Generate multiple QChem input files at once.
-        
+
         Parameters
         ----------
             args : Namespace
                 Namespace of input arguments.
             strfiles : list
                 List of xyz files produced.
-        
+
         Returns
         -------
             jobdirs : list
@@ -527,7 +530,7 @@ def qgen(args, strfiles, method):
                 List of xyz files produced.
             method : str
                 Name of method to use, (e.g. B3LYP).
-        
+
         Returns
         -------
             jobdirs : list
@@ -562,18 +565,22 @@ def qgen(args, strfiles, method):
         else:
             nametrunc = coordname
         if not os.path.exists(rdir+'/'+nametrunc) and not args.jobdir:
-            os.mkdir(rdir+'/'+nametrunc)
+            os.makedirs(rdir+'/'+nametrunc)
         mdir = rdir+'/'+nametrunc
         if method:
             mmd = '/'+method
             mdir = rdir+'/'+nametrunc+mmd
             if not os.path.exists(mdir):
-                os.mkdir(mdir)
+                os.makedirs(mdir)
 
         jobdirs.append(mdir)
         shutil.copy2(xyzf, mdir)
-        shutil.copy2(xyzf.replace('.xyz', '.molinp'),
-                     mdir.replace('.xyz', '.molinp'))
+        # Try copying molinp and report files to the new jobdir
+        try:
+            shutil.copy2(xyzf.replace('.xyz', '.molinp'),
+                         mdir.replace('.xyz', '.molinp'))
+        except FileNotFoundError:
+            pass
         try:
             shutil.copy2(xyzf.replace('.xyz', '.report'),
                          mdir.replace('.xyz', '.report'))
@@ -599,10 +606,9 @@ def qgen(args, strfiles, method):
         jobparams['CHARGE'] = args.charge
     # Now we're ready to start building the input file and the job script
     for i, jobd in enumerate(jobdirs):
-        output = open(jobd+'/qch.inp', 'w')
-        f = open(jobd+'/'+coordfs[i])
-        s0 = f.readlines()[2:]  # read coordinates
-        f.close()
+        output = []
+        with open(jobd+'/'+coordfs[i]) as f:
+            s0 = f.readlines()[2:]  # read coordinates
         # if separate split to two molecules
         if args.bsep and '--' in ''.join(s0):
             idxsplit = [isdx for isdx, ss in enumerate(s0) if '--' in ss][0]
@@ -613,16 +619,16 @@ def qgen(args, strfiles, method):
         else:
             s = s0
         # write rem block
-        output.write('$rem\nUNRESTRICTED\t\t' + jobparams['UNRESTRICTED'])
-        output.write(
+        output.append('$rem\nUNRESTRICTED\t\t' + jobparams['UNRESTRICTED'])
+        output.append(
             '\nBASIS\t\t'+jobparams['BASIS']+'\nJOBTYPE\t\t'+jobparams['JOBTYPE'])
-        output.write('\nEXCHANGE\t\t' +
-                     jobparams['EXCHANGE']+'\nCORRELATION\t\t')
-        output.write(jobparams['CORRELATION']+'\nMAX_SCF_CYCLES\t\t')
-        output.write(jobparams['MAX_SCF_CYCLES']+'\nGEOM_OPT_MAX_CYCLES\t\t')
-        output.write(jobparams['GEOM_OPT_MAX_CYCLES'] +
-                     '\nSYMMETRY\t\t'+jobparams['SYMMETRY'])
-        output.write('\nPRINT_ORBITALS\t\t'+jobparams['PRINT_ORBITALS']+'\n')
+        output.append('\nEXCHANGE\t\t' +
+                      jobparams['EXCHANGE']+'\nCORRELATION\t\t')
+        output.append(jobparams['CORRELATION']+'\nMAX_SCF_CYCLES\t\t')
+        output.append(jobparams['MAX_SCF_CYCLES']+'\nGEOM_OPT_MAX_CYCLES\t\t')
+        output.append(jobparams['GEOM_OPT_MAX_CYCLES'] +
+                      '\nSYMMETRY\t\t'+jobparams['SYMMETRY'])
+        output.append('\nPRINT_ORBITALS\t\t'+jobparams['PRINT_ORBITALS']+'\n')
         # write additional options
         if (args.remoption):
             if len(args.remoption) % 2 > 0:
@@ -630,13 +636,14 @@ def qgen(args, strfiles, method):
             else:
                 for elem in range(0, int(0.5*len(args.remoption))):
                     key, val = args.remoption[2*elem], args.remoption[2*elem+1]
-                    output.write(key+'\t\t'+val+'\n')
-        output.write('$end\n\n')
+                    output.append(key+'\t\t'+val+'\n')
+        output.append('$end\n\n')
         # write $molecule block
-        output.write(
+        output.append(
             '$molecule\n'+jobparams['CHARGE']+' '+jobparams['SPIN']+'\n')
-        output.write(''.join(s)+'$end')
-        output.close()
+        output.append(''.join(s)+'$end\n')
+        with open(jobd+'/qch.inp', 'w') as f:
+            f.writelines(output)
     return jobdirs
 
 
@@ -651,7 +658,7 @@ def mlpgen(args, strfiles, rootdir):
                 List of xyz files produced.
             rootdir : str
                 Path of the root directory.
-        
+
         Returns
         -------
             jobdirs : list
@@ -696,14 +703,13 @@ def mlpgen(args, strfiles, rootdir):
     if args.charge:
         jobparams.append('CHARGE='+str(args.charge))
     # Now we're ready to start building the input file and the job script
-    for i, jobd in enumerate(jobdirs):
-        output = open(strfiles[i] + '.mop', 'w')
-        f = open(strfiles[i]+'.xyz')
-        s = f.readlines()[2:]  # read coordinates
-        f.close()
+    for xyzf in strfiles:
+        output = []
+        with open(xyzf + '.xyz') as f:
+            s = f.readlines()[2:]  # read coordinates
         # write rem block
         for terms in jobparams:
-            output.write(' ' + terms)
+            output.append(' ' + terms)
         # write additional options
         if (args.remoption):
             if len(args.remoption) % 2 > 0:
@@ -711,19 +717,20 @@ def mlpgen(args, strfiles, rootdir):
             else:
                 for elem in range(0, int(0.5*len(args.remoption))):
                     key, val = args.remoption[2*elem], args.remoption[2*elem+1]
-                    output.write(key+'\t\t'+val+'\n')
-        output.write('\n' + nametrunc+'\n')
-        output.write('\n')
+                    output.append(key+'\t\t'+val+'\n')
+        output.append('\n' + nametrunc+'\n')
+        output.append('\n')
         # write $molecule block
         for lines in s:
             ll = lines.split('\t')
             for i, items in enumerate(ll):
-                output.write(' ' + items.strip('\n'))
+                output.append(' ' + items.strip('\n'))
                 if i > 0:
-                    output.write(' 1')
+                    output.append(' 1')
                 if i == 3:
-                    output.write('\n')
-        output.close()
+                    output.append('\n')
+        with open(xyzf + '.mop', 'w') as f:
+            f.writelines(output)
     return jobdirs
 
 
@@ -736,7 +743,7 @@ def multiogen(args, strfiles):
                 Namespace of input arguments.
             strfiles : list
                 List of xyz files produced.
-            
+
         Returns
         -------
             jobdirs : list
@@ -775,7 +782,7 @@ def ogen(args, strfiles, method):
                 List of xyz files produced.
             method : str
                 Method to be used (e.g. B3LYP)
-            
+
         Returns
         -------
             jobdirs : list
@@ -878,7 +885,7 @@ def ogen(args, strfiles, method):
     # Special sanity check for CCSD(T)
     if jobparams['run'] == 'Opt' and 'CC' in jobparams['method']:
         print('''Warning! You requested geometry optimization with Coupled-Cluster methods,
-                which is NOT supported. Instead, we will geometry optimize the structure 
+                which is NOT supported. Instead, we will geometry optimize the structure
                 with B3LYP and then conduct CCSD(T) energy calculation on the optimized structure''')
     # TODO: check ORCA dispersion
     if (args.dispersion):
@@ -926,33 +933,31 @@ def ogen(args, strfiles, method):
     # Now we're ready to start building the input file
     if not args.jobdir:
         for i, jobd in enumerate(jobdirs):
-            output = open(jobd+'/orca.in', 'w')
-            output.write('# file created with %s\n' % globs.PROGRAM)
-            if 'CC' in jobparams['method'] and jobparams['run'] == 'Opt':
-                params0 = jobparams.copy()
-                params0['method'] = 'B3LYP'
-                ogenwrt(output, params0, coordfs[i])
-                output.write('\n$new_job\n')
-                jobparams['run'] = 'Sp'
-                ogenwrt(output, jobparams, '')
-            else:
-                ogenwrt(output, jobparams, coordfs[i])
-            output.close()
+            with open(jobd+'/orca.in', 'w') as output:
+                output.write('# file created with %s\n' % globs.PROGRAM)
+                if 'CC' in jobparams['method'] and jobparams['run'] == 'Opt':
+                    params0 = jobparams.copy()
+                    params0['method'] = 'B3LYP'
+                    ogenwrt(output, params0, coordfs[i])
+                    output.write('\n$new_job\n')
+                    jobparams['run'] = 'Sp'
+                    ogenwrt(output, jobparams, '')
+                else:
+                    ogenwrt(output, jobparams, coordfs[i])
     elif args.jobdir:
         for i, jobd in enumerate(jobdirs):
             print(('jobd is ' + jobd))
-            output = open(jobd+'/orca.in', 'w')
-            output.write('# file created with %s\n' % globs.PROGRAM)
-            if 'CC' in jobparams['method'] and jobparams['run'] == 'Opt':
-                params0 = jobparams.copy()
-                params0['method'] = 'B3LYP'
-                ogenwrt(output, params0, coordfs[i])
-                output.write('\n$new_job\n')
-                jobparams['run'] = 'Sp'
-                ogenwrt(output, jobparams, '')
-            else:
-                ogenwrt(output, jobparams, coordfs[i])
-            output.close()
+            with open(jobd+'/orca.in', 'w') as output:
+                output.write('# file created with %s\n' % globs.PROGRAM)
+                if 'CC' in jobparams['method'] and jobparams['run'] == 'Opt':
+                    params0 = jobparams.copy()
+                    params0['method'] = 'B3LYP'
+                    ogenwrt(output, params0, coordfs[i])
+                    output.write('\n$new_job\n')
+                    jobparams['run'] = 'Sp'
+                    ogenwrt(output, jobparams, '')
+                else:
+                    ogenwrt(output, jobparams, coordfs[i])
     return jobdirs
 
 
@@ -967,7 +972,7 @@ def ogenwrt(output, jobparams, xyzf):
                 Dictionary of ORCA input parameters.
             xyzf : str
                 Name for XYZ file.
-            
+
         Returns
         -------
             jobdirs : list
@@ -988,9 +993,10 @@ def ogenwrt(output, jobparams, xyzf):
     # write the scf control block
     output.write('%scf\n')
     output.write('MaxIter '+jobparams['MaxIter']+'\n')
-    if jobparams['levelshift'] == 'yes':
-        output.write(
-            'Shift Shift '+str(jobparams['levelshiftval'])+' ErrOff ' + str(jobparams['ErrOff'])+'  end\n')
+    if 'levelshift' in jobparams:
+        if jobparams['levelshift'] == 'yes':
+            output.write('Shift Shift '+str(jobparams['levelshiftval'])
+                         + ' ErrOff ' + str(jobparams['ErrOff'])+'  end\n')
     output.write('DIISMaxEq '+str(jobparams['DIISMaxEq'])+'\n')
     output.write('end\n\n')
     # write the method block to control HFX
@@ -1025,7 +1031,7 @@ def molcgen(args, strfiles, method):
                 List of xyz files produced.
             method : str
                 Method to be used (e.g. B3LYP)
-            
+
         Returns
         -------
             jobdirs : list
@@ -1162,17 +1168,15 @@ def molcgen(args, strfiles, method):
     # Now we're ready to start building the input file
     if not args.jobdir:
         for i, jobd in enumerate(jobdirs):
-            output = open(jobd+'/molcas.input', 'w')
-            output.write('# file created with %s\n' % globs.PROGRAM)
-            molcwrt(output, jobparams, coordfs[i], i)
-            output.close()
+            with open(jobd+'/molcas.input', 'w') as output:
+                output.write('# file created with %s\n' % globs.PROGRAM)
+                molcwrt(output, jobparams, coordfs[i], i)
     elif args.jobdir:
         for i, jobd in enumerate(jobdirs):
             print(('jobd is ' + jobd))
-            output = open(jobd+'/molcas.input', 'w')
-            output.write('# file created with %s\n' % globs.PROGRAM)
-            molcwrt(output, jobparams, coordfs[i], i)
-            output.close()
+            with open(jobd+'/molcas.input', 'w') as output:
+                output.write('# file created with %s\n' % globs.PROGRAM)
+                molcwrt(output, jobparams, coordfs[i], i)
     return jobdirs
 
 
@@ -1189,7 +1193,7 @@ def molcwrt(output, jobparams, xyzf, xyzind):
                 Name for XYZ file.
             xyzind : int
                 Index for xyz file in all generated xyz files
-            
+
         Returns
         -------
             jobdirs : list
@@ -1236,7 +1240,7 @@ def multimolcgen(args, strfiles):
                 Namespace of input arguments.
             strfiles : list
                 List of xyz files produced.
-            
+
         Returns
         -------
             jobdirs : list
@@ -1272,7 +1276,7 @@ def molcbasis(strfiles, basistyp):
                 List of XYZ files produced
             basistyp : str
                 The basis set.
-            
+
         Returns
         -------
             basis : str
@@ -1350,7 +1354,7 @@ def molcras2s(strfiles):
         ----------
             strfiles : list
                 List of XYZ files produced
-            
+
         Returns
         -------
             ras2s : list
@@ -1384,7 +1388,7 @@ def molcnactels(strfiles, oxnum):
                 List of XYZ files produced
             oxnum : int
                 Oxidation state.
-            
+
         Returns
         -------
             nactels : list
@@ -1417,7 +1421,7 @@ def molcfrozens(strfiles):
         ----------
             strfiles : list
                 List of XYZ files produced
-            
+
         Returns
         -------
             frozens : list
