@@ -13,6 +13,7 @@ import sys
 from collections import Counter
 import glob
 
+from molSimplify.Classes.globalvars import globalvars
 from molSimplify.Scripts.isomers import generateisomers
 from molSimplify.Scripts.jobgen import (sgejobgen,
                                         slurmjobgen)
@@ -42,7 +43,7 @@ if sys.version_info[:2] <= (2, 7):
 #####################################
 
 
-def constrgen(rundir, args, globs):
+def constrgen(rundir, args):
     emsg = False
     # load global variables
     licores = getlicores()
@@ -110,7 +111,7 @@ def constrgen(rundir, args, globs):
             args.lig = [a for a in ligs0]
             args.ligocc = [int(a) for a in ligocc0]
             # run structure generation
-            emsg = rungen(rundir, args, False, globs)
+            emsg = rungen(rundir, args)
         else:
             if args.gui:
                 from molSimplify.Classes.mWidgets import mQDialogErr
@@ -140,7 +141,7 @@ def constrgen(rundir, args, globs):
                 args.keepHs.append(opt)
             else:
                 args.keepHs = [opt]
-        emsg = rungen(rundir, args, False, globs)  # run structure generation
+        emsg = rungen(rundir, args)  # run structure generation
     return args, emsg
 
 
@@ -198,7 +199,7 @@ def getconstsample(no_rgen, args, licores, coord):
 #  @return Error messages
 
 
-def multigenruns(rundir, args, globs, write_files=True):
+def multigenruns(rundir, args, write_files=True):
     emsg = False
     args.jid = 0  # initilize global name identifier
     multch = False
@@ -212,7 +213,6 @@ def multigenruns(rundir, args, globs, write_files=True):
     if (args.spin and len(args.spin) > 1):
         multsp = True
     # iterate over all
-    fname = False
     if (multch and multsp):
         for ch in charges:
             for sp in spins:
@@ -222,10 +222,7 @@ def multigenruns(rundir, args, globs, write_files=True):
                     fname = 'N'+ch[1:]+'S'+sp
                 else:
                     fname = 'P'+ch+'S'+sp
-                # if args.tsgen:
-                #     emsg = tsgen_supervisor(rundir,args,fname,globs)
-                # else:
-                emsg = rungen(rundir, args, fname, globs, write_files=write_files)
+                emsg = rungen(rundir, args, fname, write_files=write_files)
                 if emsg:
                     return emsg
     elif (multch):
@@ -237,10 +234,7 @@ def multigenruns(rundir, args, globs, write_files=True):
                 fname = 'N'+ch[1:]
             else:
                 fname = 'P'+ch[1:]
-            # if args.tsgen:
-            #     emsg = tsgen_supervisor(rundir,args,fname,globs)
-            # else:
-            emsg = rungen(rundir, args, fname, globs, write_files=write_files)
+            emsg = rungen(rundir, args, fname, write_files=write_files)
             if emsg:
                 return emsg
     elif (multsp):
@@ -249,10 +243,7 @@ def multigenruns(rundir, args, globs, write_files=True):
         for sp in spins:
             args.spin = sp
             fname = 'S'+sp
-            # if args.tsgen:
-            #     emsg = tsgen_supervisor(rundir,args,fname,globs)
-            # else:
-            emsg = rungen(rundir, args, fname, globs, write_files=write_files)
+            emsg = rungen(rundir, args, fname, write_files=write_files)
             if emsg:
                 return emsg
     elif args.isomers or args.stereos:
@@ -296,17 +287,14 @@ def multigenruns(rundir, args, globs, write_files=True):
             print(('******************* Generating isomer ' +
                   str(counter+1) + '! *******************'))
             print('**************************************************************')
-            emsg = rungen(rundir, args, fname, globs, write_files=write_files)
+            emsg = rungen(rundir, args, write_files=write_files)
         return emsg
     else:
         if args.charge:
             args.charge = args.charge[0]
         if args.spin:
             args.spin = args.spin[0]
-        # if args.tsgen:
-        #     emsg = tsgen_supervisor(rundir,args,fname,globs)
-        # else:
-        emsg = rungen(rundir, args, fname, globs, write_files=write_files)
+        emsg = rungen(rundir, args, write_files=write_files)
     return emsg
 
 # Check for multiple ligands specified in one file
@@ -377,7 +365,8 @@ def draw_supervisor(args, rundir):
             print('Due to technical limitations, we will draw only the first core.')
         print('Drawing the core.')
         if args.substrate:
-            print('Due to technical limitations, we can draw only one structure per run. To draw the substrate, run the program again.')
+            print('Due to technical limitations, we can draw only one structure per run. '
+                  'To draw the substrate, run the program again.')
         cc, emsg = core_load(args.core[0])
         cc.draw_svg(args.core[0])
     elif args.substrate:
@@ -394,29 +383,23 @@ def draw_supervisor(args, rundir):
 #  @param rundir Run directory
 #  @param args Namespace of arguments
 #  @param chspfname Folder name for charges and spins
-#  @param globs Global variables
 #  @return Error messages
 
 
-def rungen(rundir, args, chspfname, globs, write_files=True):
-    try:
-        from Classes.mWidgets import mQDialogInf
-    except ImportError:
-        args.gui = False
-    emsg = False
+def rungen(rundir, args, chspfname=None, write_files=True):
+    emsg = ''
+    globs = globalvars()
     globs.nosmiles = 0  # reset smiles ligands for each run
     # check for specified ligands/functionalization
     ligocc = []
     # check for files specified for multiple ligands
     mligs, catoms = [False], [False]
     if args.lig is not None:
-        if '.smi' in args.lig[0]:
-            ligfilename = args.lig[0].split('.')[0]
         if args.lig:
             mligs, catoms, multidx = checkmultilig(args.lig)
-        if args.debug:
-            print(('after checking for mulitple ligs, we found  ' +
-                   str(multidx) + ' ligands'))
+            if args.debug:
+                print('after checking for multiple ligs, we found '
+                      f'{multidx} ligands')
     # save initial
     smicat0 = [ss for ss in args.smicat] if args.smicat else False
     # loop over ligands
@@ -477,14 +460,14 @@ def rungen(rundir, args, chspfname, globs, write_files=True):
             mligcatoms = args.mligcatoms
             fname = name_ts_complex(rundir, args.core, args.geometry, ligands, ligocc, substrate, subcatoms,
                                     mlig, mligcatoms, mcount, args, nconf=False, sanity=False, bind=args.bind, bsmi=args.nambsmi)
-        if globs.debug:
+        if args.debug:
             print(('fname is ' + str(fname)))
         rootdir = fname
         # check for charges/spin
         rootcheck = False
-        if (chspfname):
+        if chspfname is not None:
             rootcheck = rootdir
-            rootdir = rootdir + '/'+chspfname
+            rootdir = rootdir + '/' + chspfname
         if (args.suff):
             rootdir += args.suff
         # check for mannual overwrite of
@@ -522,14 +505,14 @@ def rungen(rundir, args, chspfname, globs, write_files=True):
                     rootcheck += '_'+str(ifold)
                     os.mkdir(rootcheck)
         elif rootcheck and (not os.path.isdir(rootcheck) or not args.checkdirt) and not skip:
-            if globs.debug:
+            if args.debug:
                 print(('rootcheck is  ' + str(rootcheck)))
             args.checkdirt = True
             try:
                 os.mkdir(rootcheck)
             except FileExistsError:
-                print(('Directory '+rootcheck+' can not be created. Exiting..\n'))
-                return
+                print(f'Directory {rootcheck} can not be created. Exiting..\n')
+                return f'Directory {rootcheck} can not be created. Exiting..'
             # check for actual directory
         if os.path.isdir(rootdir) and not args.checkdirb and not skip and not args.jobdir:
             args.checkdirb = True
@@ -647,12 +630,14 @@ def rungen(rundir, args, chspfname, globs, write_files=True):
                 elif args.jsched in 'SGE Sungrid sge':
                     sgejobgen(args, jobdirs)
                     print('SGE jobscripts generated!')
-
             elif multidx != -1:  # if ligand input was a list of smiles strings, write good smiles strings to separate list
-                with open(ligfilename+'-good.smi', 'a') as f:
-                    f.write(args.lig[0])
+                if '.smi' in args.lig[0]:
+                    ligfilename = args.lig[0].split('.')[0]
+                    with open(ligfilename + '-good.smi', 'a') as f:
+                        f.write(args.lig[0])
         elif not emsg:
             if args.gui:
+                from Classes.mWidgets import mQDialogInf
                 qq = mQDialogInf('Folder skipped', 'Folder ' +
                                  rootdir+' was skipped.')
                 qq.setParent(args.gui.wmain)
@@ -660,5 +645,5 @@ def rungen(rundir, args, chspfname, globs, write_files=True):
                 print(('Folder '+rootdir+' was skipped..\n'))
     if write_files:
         return emsg  # Default behavior
-    else:
-        return strfiles, emsg, this_diag  # Assume that user wants these if they're not writing files
+    # else:
+    return strfiles, emsg, this_diag  # Assume that user wants these if they're not writing files
