@@ -14,7 +14,10 @@ try:
     import pymol
 except ImportError:
     pass
-import openbabel
+try:
+    from openbabel import openbabel  # version 3 style import
+except ImportError:
+    import openbabel  # fallback to version 2
 
 from molSimplify.Classes.globalvars import (amassdict,
                                             glob,
@@ -430,14 +433,12 @@ def dbsearch(rundir, args, globs):
     flag = False
 
     obab = 'obabel'
-    if args.gui:
-        from molSimplify.Classes.mWidgets import mQDialogWarn
-        from molSimplify.Classes.mWidgets import mQDialogInf
     ### in any case do similarity search over indexed db ###
     outf = args.dbfname if args.dbfname else 'simres.smi'  # output file
     # convert to SMILES/SMARTS if file
     if not args.dbbase:
         if args.gui:
+            from molSimplify.Classes.mWidgets import mQDialogWarn
             qqb = mQDialogWarn('Warning', "No database file found within " +
                                globs.chemdbdir + '. Search not possible.')
             qqb.setParent(args.gui.DBWindow)
@@ -541,6 +542,7 @@ def dbsearch(rundir, args, globs):
     nmols = '10000' if not args.dbnsearch else args.dbnsearch
     finger = 'FP2' if not args.dbfinger else args.dbfinger
     if int(nmols) > 3000 and args.gui:
+        from molSimplify.Classes.mWidgets import mQDialogInf
         qqb = mQDialogInf(
             'Warning', "Database search is going to take a few minutes. Please wait..OK?")
         qqb.setParent(args.gui.DBWindow)
@@ -556,6 +558,7 @@ def dbsearch(rundir, args, globs):
         print(('after similarity search, outf is ' + str(outputf)))
     if flag:
         if args.gui:
+            from molSimplify.Classes.mWidgets import mQDialogWarn
             qqb = mQDialogWarn('Warning', "No matches found in search..")
             qqb.setParent(args.gui.DBWindow)
         print("No matches found in search..")
@@ -567,10 +570,9 @@ def dbsearch(rundir, args, globs):
 
         print(('number of smiles strings BEFORE salt stripping: ' +
                mybash("cat " + outf + '| wc -l')))
-        flag = stripsalts(outf)
+        _ = stripsalts(outf)
         print(('number of smiles strings AFTER salt stripping: ' +
                mybash("cat " + outf + '| wc -l')))
-        # print('flag from salt stripping: ' + str(flag))
         print(('number of smiles strings BEFORE unique: ' +
                mybash("cat " + outf + '| wc -l')))
         cmd = obab + " -ismi " + outf + " -osmi -O " + outf + " --unique"
@@ -608,7 +610,7 @@ def dbsearch(rundir, args, globs):
     if args.dbsmarts or args.dbhuman:
         print(('number of smiles strings BEFORE SMARTS filter: ' +
                mybash("cat " + outf + '| wc -l')))
-        flag = matchsmarts(smistr, outf, catoms, args)
+        _ = matchsmarts(smistr, outf, catoms, args)
         print(('number of smiles strings AFTER SMARTS filter: ' +
                mybash("cat " + outf + '| wc -l')))
     if args.debug:
