@@ -8,6 +8,7 @@ import molSimplify.job_manager.moltools as moltools
 from molSimplify.job_manager.classes import resub_history
 import molSimplify.job_manager.manager_io as manager_io
 
+
 def load_history(PATH):
     """Load a resub history object.
 
@@ -20,7 +21,7 @@ def load_history(PATH):
     -------
         history : resub_history
             resub_history class instance for history object of job.
-        
+
     """
     # takes the path to either an outfile or the resub_history pickle
     # returns the resub_history class object
@@ -29,15 +30,16 @@ def load_history(PATH):
     history.read(PATH)
     return history
 
+
 def abandon_job(PATH):
     """Abandons a job with a given path. This function is never and should never be called by the job manager.
-    Only called manually for troublesome jobs. 
+    Only called manually for troublesome jobs.
 
     Parameters
     ----------
         PATH : str
             The name of an output file or history object pickle file.
-        
+
     """
     # takes the path to either an outfile or the resub_history pickle
     # sets the jobs status to be abandoned
@@ -48,8 +50,9 @@ def abandon_job(PATH):
     history.abandon()
     history.save()
 
+
 def save_scr(outfile_path, rewrite_inscr=True):
-    """Archive the scr file so it isn't overwritten in future resubs. 
+    """Archive the scr file so it isn't overwritten in future resubs.
 
     Parameters
     ----------
@@ -63,7 +66,7 @@ def save_scr(outfile_path, rewrite_inscr=True):
         scrpaths : str
             Path to new scr directory.
 
-        
+
     """
     root = os.path.split(outfile_path)[0]
     scr_path = os.path.join(root, 'scr')
@@ -101,8 +104,9 @@ def save_scr(outfile_path, rewrite_inscr=True):
 
         return os.path.join(os.path.split(outfile_path)[0], 'scr') + '_' + new_scr
 
+
 def save_run(outfile_path, rewrite_inscr=True, save_scr_flag=True):
-    """Save the outfile within the resub_history pickle object. 
+    """Save the outfile within the resub_history pickle object.
 
     Parameters
     ----------
@@ -112,13 +116,12 @@ def save_run(outfile_path, rewrite_inscr=True, save_scr_flag=True):
             Determines whether to copy this runs wfn and optimized geometry to the inscr directory. Default is True.
         save_scr_flag : bool, optional
             Determine wheether to store scr. Default is True.
-        
+
     """
     def write(list_of_lines, path):
-        fil = open(path, 'w')
-        for i in list_of_lines:
-            fil.write(i)
-        fil.close()
+        with open(path, 'w') as fil:
+            for i in list_of_lines:
+                fil.write(i)
 
     if save_scr_flag:
         scr_path = save_scr(outfile_path, rewrite_inscr=rewrite_inscr)
@@ -128,27 +131,23 @@ def save_run(outfile_path, rewrite_inscr=True, save_scr_flag=True):
     history = resub_history()
     history.read(outfile_path)
 
-    f = open(outfile_path, 'r')
-    out_lines = f.readlines()
-    f.close()
+    with open(outfile_path, 'r') as f:
+        out_lines = f.readlines()
     history.outfiles.append(out_lines)
 
     infile_path = outfile_path.rsplit('.', 1)[0] + '.in'
-    f = open(infile_path, 'r')
-    in_lines = f.readlines()
-    f.close()
+    with open(infile_path, 'r') as f:
+        in_lines = f.readlines()
     history.infiles.append(in_lines)
 
     jobscript_path = outfile_path.rsplit('.', 1)[0] + '_jobscript'
-    f = open(jobscript_path, 'r')
-    job_lines = f.readlines()
-    f.close()
+    with open(jobscript_path, 'r') as f:
+        job_lines = f.readlines()
     history.jobscripts.append(job_lines)
 
     xyz_path = outfile_path.rsplit('.', 1)[0] + '.xyz'
-    f = open(xyz_path, 'r')
-    xyz_lines = f.readlines()
-    f.close()
+    with open(xyz_path, 'r') as f:
+        xyz_lines = f.readlines()
     history.xyzs.append(xyz_lines)
 
     history.save()
@@ -163,14 +162,15 @@ def save_run(outfile_path, rewrite_inscr=True, save_scr_flag=True):
         write(xyz_lines, 'old_xyz')
         os.chdir(home)
 
+
 def reset(outfile_path):
-    """Returns the run to the state it was after the first run, before job recovery acted on it. 
+    """Returns the run to the state it was after the first run, before job recovery acted on it.
 
     Parameters
     ----------
         outfile_path : str
             The name of an output file.
-   
+
     """
     # Returns the run to the state it was after the first run, before job recovery acted on it
 
@@ -239,26 +239,23 @@ def reset(outfile_path):
         infile = history.infiles[0]
         jobscript = history.jobscripts[0]
         xyz = history.xyzs[0]
-        writer = open(outfile_path, 'w')
-        for i in outfile:
-            writer.write(i)
-        writer.close()
-        writer = open(outfile_path.rsplit('.', 1)[0] + '.in', 'w')
-        for i in infile:
-            writer.write(i)
-        writer.close()
-        writer = open(outfile_path.rsplit('.', 1)[0] + '.xyz', 'w')
-        for i in xyz:
-            writer.write(i)
-        writer.close()
-        writer = open(outfile_path.rsplit('.', 1)[0] + '_jobscript', 'w')
-        for i in jobscript:
-            writer.write(i)
-        writer.close()
+        with open(outfile_path, 'w') as writer:
+            for i in outfile:
+                writer.write(i)
+        with open(outfile_path.rsplit('.', 1)[0] + '.in', 'w') as writer:
+            for i in infile:
+                writer.write(i)
+        with open(outfile_path.rsplit('.', 1)[0] + '.xyz', 'w') as writer:
+            for i in xyz:
+                writer.write(i)
+        with open(outfile_path.rsplit('.', 1)[0] + '_jobscript', 'w') as writer:
+            for i in jobscript:
+                writer.write(i)
 
         shutil.move(scr_path + '_0', scr_path)
         shutil.move(pickle_path, os.path.join(old_path, str(np.random.randint(999999999)) + '_resub_history'))
 
+
 def simple_resub(outfile_path):
     """Resubmits a job without changing parameters. Particularly useful for CUDA errors.
 
@@ -266,12 +263,12 @@ def simple_resub(outfile_path):
     ----------
         outfile_path : str
             The name of an output file.
-    
+
     Returns
     -------
         Resub_flag : bool
             True if resubmitted.
-   
+
     """
     # Resubmits a job without changing parameters. Particularly useful for CUDA errors.
     save_run(outfile_path, rewrite_inscr=False)
@@ -286,6 +283,7 @@ def simple_resub(outfile_path):
     tools.qsub(root + '_jobscript')
     return True
 
+
 def clean_resub(outfile_path):
     """Resubmits a job with default parameters, useful for undoing level shift or hfx alterations.
 
@@ -293,12 +291,12 @@ def clean_resub(outfile_path):
     ----------
         outfile_path : str
             The name of an output file.
-    
+
     Returns
     -------
         Resub_flag : bool
             True if resubmitted.
-   
+
     """
     # Resubmits a job with default parameters, useful for undoing level shift or hfx alterations
     save_run(outfile_path)
@@ -348,6 +346,7 @@ def clean_resub(outfile_path):
     tools.qsub(root + '_jobscript')
     return True
 
+
 def resub_spin(outfile_path):
     """Resubmits a spin contaminated job with blyp to help convergence to a non-spin contaminated solution.
 
@@ -355,12 +354,12 @@ def resub_spin(outfile_path):
     ----------
         outfile_path : str
             The name of an output file.
-    
+
     Returns
     -------
         Resub_flag : bool
             True if resubmitted.
-   
+
     """
     # resubmits a spin contaminated job with blyp to help convergence to a non-spin contaminated solution
     history = resub_history()
@@ -414,6 +413,7 @@ def resub_spin(outfile_path):
     else:
         return False
 
+
 def resub_scf(outfile_path):
     """Resubmits a job that's having trouble converging the scf with different level shifts (1.0 and 0.1).
 
@@ -421,12 +421,12 @@ def resub_scf(outfile_path):
     ----------
         outfile_path : str
             The name of an output file.
-    
+
     Returns
     -------
         Resub_flag : bool
             True if resubmitted.
-   
+
     """
     # Resubmits a job that's having trouble converging the scf with different level shifts (1.0 and 0.1)
     history = resub_history()
@@ -474,6 +474,7 @@ def resub_scf(outfile_path):
     else:
         return False
 
+
 def resub_oscillating_scf(outfile_path):
     """Resubmits a job that's having trouble converging the scf with different level shifts (1.0 and 0.1).
 
@@ -481,12 +482,12 @@ def resub_oscillating_scf(outfile_path):
     ----------
         outfile_path : str
             The name of an output file.
-    
+
     Returns
     -------
         Resub_flag : bool
             True if resubmitted.
-   
+
     """
 
     # Resubmits a job that's having trouble converging the scf with different level shifts (1.0 and 0.1)
@@ -533,6 +534,7 @@ def resub_oscillating_scf(outfile_path):
     else:
         return False
 
+
 def resub_bad_geo(outfile_path, home_directory):
     """Resubmits a job that's converged to a bad geometry with additional contraints.
 
@@ -542,12 +544,12 @@ def resub_bad_geo(outfile_path, home_directory):
             The name of an output file.
         home_directory : str
             Path to the base directory of the run.
-    
+
     Returns
     -------
         Resub_flag : bool
             True if resubmitted.
-   
+
     """
     # Resubmits a job that's converged to a bad geometry with additional contraints
     history = resub_history()
@@ -612,20 +614,21 @@ def resub_bad_geo(outfile_path, home_directory):
     else:
         return False
 
+
 def resub_tighter(outfile_path):
-    """Resubmits a thermo job with the gradient error problem. Finds the parent job and resubmits it with a tighter scf 
+    """Resubmits a thermo job with the gradient error problem. Finds the parent job and resubmits it with a tighter scf
     convergence criteria.
 
     Parameters
     ----------
         outfile_path : str
             The name of an output file.
-    
+
     Returns
     -------
         Resub_flag : bool
             True if resubmitted.
-   
+
     """
     # Takes the path to the outfile of a thermo job with the gradient error problem
     # Finds the parent job and resubmits it with a tighter scf convergence criteria
@@ -662,21 +665,22 @@ def resub_tighter(outfile_path):
 
     return True
 
+
 def resub_thermo(outfile_path):
     """Similar to simple resub, but specific for addressing thermo gradient errors.
-    hecks for the existance of an ultratight version of this run. If it exists, 
+    hecks for the existance of an ultratight version of this run. If it exists,
     uses the most up to date version for the new thermo run
 
     Parameters
     ----------
         outfile_path : str
             The name of an output file.
-    
+
     Returns
     -------
         Resub_flag : bool
             True if resubmitted.
-   
+
     """
     # Similar to simple resub, but specific for addressing thermo gradient errors
     # Checks for the existance of an ultratight version of this run. If it exists, uses the most up to date version for the new thermo run
