@@ -8,7 +8,7 @@ crduan@mit.edu, hjkulik@mit.edu
 
 import sys
 import tensorflow as tf
-import keras
+from tensorflow import keras
 from molSimplify.molscontrol.io_tools import get_configure
 from molSimplify.molscontrol.dynamic_classifier import dft_control
 import argparse
